@@ -26,7 +26,7 @@ CONTACT_MAILING_STATUS = (
 
 
 class Contact(models.Model):
-    email = models.EmailField(_('e-mail'))
+    email = models.EmailField(_('e-mail'), unique=True)
     first_name = models.CharField(_('first name'), max_length=64, blank=True)
     last_name = models.CharField(_('last name'), max_length=64, blank=True)
     mailing_lists = models.ManyToManyField(
